<?php
/**
 * The default template for displaying content
 *
 * Used for index/archive/search.
 *
 * @package WordPress
 * @subpackage MANDALA
 * @since MANDALA 1.0
 */

$mandala_post_format = get_post_format();
$mandala_post_format = empty($mandala_post_format) ? 'standard' : str_replace('post-format-', '', $mandala_post_format);
$mandala_full_content = mandala_get_theme_option('blog_content') != 'excerpt' || in_array($mandala_post_format, array('link', 'aside', 'status', 'quote'));
$mandala_animation = mandala_get_theme_option('blog_animation');

?><article id="post-<?php the_ID(); ?>" 
	<?php post_class( 'post_item post_layout_excerpt post_format_'.esc_attr($mandala_post_format) ); ?>
	<?php echo (!mandala_is_off($mandala_animation) ? ' data-animation="'.esc_attr(mandala_get_animation_classes($mandala_animation)).'"' : ''); ?>
	><?php

	// Featured image
	mandala_show_post_featured(array( 'thumb_size' => mandala_get_thumb_size( strpos(mandala_get_theme_option('body_style'), 'full')!==false ? 'full' : 'big' ) ));

	// Title and post meta
	if (get_the_title() != '') {
		?>
		<div class="post_header entry-header">
			<?php
			do_action('mandala_action_before_post_title'); 

			// Post title
			the_title( sprintf( '<h3 class="post_title entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h3>' );

			do_action('mandala_action_before_post_meta'); 

			// Post meta
			mandala_show_post_meta(array(
				'categories' => false,
				'date' => true,
				'edit' => false,
				'seo' => false,
				'share' => false,
				'counters' => 'comments'	//comments,likes,views - comma separated in any combination
				)
			);
			?>
		</div><!-- .post_header --><?php
	}
	
	// Post content
	?><div class="post_content entry-content"><?php
		if ($mandala_full_content) {
			// Post content area
			?><div class="post_content_inner"><?php
				the_content( '' );
			?></div><?php
			// Inner pages
			wp_link_pages( array(
				'before'      => '<div class="page_links"><span class="page_links_title">' . esc_html__( 'Pages:', 'mandala' ) . '</span>',
				'after'       => '</div>',
				'link_before' => '<span>',
				'link_after'  => '</span>',
				'pagelink'    => '<span class="screen-reader-text">' . esc_html__( 'Page', 'mandala' ) . ' </span>%',
				'separator'   => '<span class="screen-reader-text">, </span>',
			) );

		} else {

			$mandala_show_learn_more = !in_array($mandala_post_format, array('link', 'aside', 'status', 'quote'));

			// Post content area
			?><div class="post_content_inner"><?php
				if (has_excerpt()) {
					the_excerpt();
				} else if (strpos(get_the_content('!--more'), '!--more')!==false) {
					the_content( '' );
				} else if (in_array($mandala_post_format, array('link', 'aside', 'status', 'quote'))) {
					the_content();
				} else if (substr(get_the_content(), 0, 1)!='[') {
					the_excerpt();
				}
			?></div><?php
			// More button
			if ( $mandala_show_learn_more ) {
				?><div class="sc_item_button sc_button_wrap">
						<a href="<?php the_permalink(); ?>" class="more-link sc_button sc_button_default sc_button_size_large sc_button_icon_right sc_button_hover_slide_left">
							<span class="sc_button_icon">
								<span class="icon-right-small"></span>
							</span>
							<span class="sc_button_text">
								<span class="sc_button_title"><?php esc_html_e('discover more', 'mandala'); ?></span>
							</span>
						</a>
					</div><?php
			}

		}
	?></div><!-- .entry-content -->
</article>