<?php
/**
 * Theme lists
 *
 * @package WordPress
 * @subpackage MANDALA
 * @since MANDALA 1.0
 */

// Disable direct call
if ( ! defined( 'ABSPATH' ) ) { exit; }



// Return numbers range
if ( !function_exists( 'mandala_get_list_range' ) ) {
	function mandala_get_list_range($from=1, $to=2, $prepend_inherit=false) {
		$list = array();
		for ($i=$from; $i<=$to; $i++)
			$list[$i] = $i;
		return $prepend_inherit ? mandala_array_merge(array('inherit' => esc_html__("Inherit", 'mandala')), $list) : $list;
	}
}



// Return styles list
if ( !function_exists( 'mandala_get_list_styles' ) ) {
	function mandala_get_list_styles($from=1, $to=2, $prepend_inherit=false) {
		$list = array();
		for ($i=$from; $i<=$to; $i++)
			$list[$i] = sprintf(esc_html__('Style %d', 'mandala'), $i);
		return $prepend_inherit ? mandala_array_merge(array('inherit' => esc_html__("Inherit", 'mandala')), $list) : $list;
	}
}

// Return list with 'Yes' and 'No' items
if ( !function_exists( 'mandala_get_list_yesno' ) ) {
	function mandala_get_list_yesno($prepend_inherit=false) {
		$list = array(
			"yes"	=> esc_html__("Yes", 'mandala'),
			"no"	=> esc_html__("No", 'mandala')
		);
		return $prepend_inherit ? mandala_array_merge(array('inherit' => esc_html__("Inherit", 'mandala')), $list) : $list;
	}
}

// Return list with 'On' and 'Of' items
if ( !function_exists( 'mandala_get_list_onoff' ) ) {
	function mandala_get_list_onoff($prepend_inherit=false) {
		$list = array(
			"on"	=> esc_html__("On", 'mandala'),
			"off"	=> esc_html__("Off", 'mandala')
		);
		return $prepend_inherit ? mandala_array_merge(array('inherit' => esc_html__("Inherit", 'mandala')), $list) : $list;
	}
}

// Return list with 'Show' and 'Hide' items
if ( !function_exists( 'mandala_get_list_showhide' ) ) {
	function mandala_get_list_showhide($prepend_inherit=false) {
		$list = array(
			"show" => esc_html__("Show", 'mandala'),
			"hide" => esc_html__("Hide", 'mandala')
		);
		return $prepend_inherit ? mandala_array_merge(array('inherit' => esc_html__("Inherit", 'mandala')), $list) : $list;
	}
}

// Return list with 'Horizontal' and 'Vertical' items
if ( !function_exists( 'mandala_get_list_directions' ) ) {
	function mandala_get_list_directions($prepend_inherit=false) {
		$list = array(
			"horizontal" => esc_html__("Horizontal", 'mandala'),
			"vertical"   => esc_html__("Vertical", 'mandala')
		);
		return $prepend_inherit ? mandala_array_merge(array('inherit' => esc_html__("Inherit", 'mandala')), $list) : $list;
	}
}

// Return list of the animations
if ( !function_exists( 'mandala_get_list_animations' ) ) {
	function mandala_get_list_animations($prepend_inherit=false) {
		$list = array(
			'none'			=> esc_html__('- None -',	'mandala'),
			'bounced'		=> esc_html__('Bounced',	'mandala'),
			'elastic'		=> esc_html__('Elastic',	'mandala'),
			'flash'			=> esc_html__('Flash',		'mandala'),
			'flip'			=> esc_html__('Flip',		'mandala'),
			'pulse'			=> esc_html__('Pulse',		'mandala'),
			'rubberBand'	=> esc_html__('Rubber Band','mandala'),
			'shake'			=> esc_html__('Shake',		'mandala'),
			'swing'			=> esc_html__('Swing',		'mandala'),
			'tada'			=> esc_html__('Tada',		'mandala'),
			'wobble'		=> esc_html__('Wobble',		'mandala')
		);
		return $prepend_inherit ? mandala_array_merge(array('inherit' => esc_html__("Inherit", 'mandala')), $list) : $list;
	}
}


// Return list of the enter animations
if ( !function_exists( 'mandala_get_list_animations_in' ) ) {
	function mandala_get_list_animations_in($prepend_inherit=false) {
		$list = array(
			'none'				=> esc_html__('- None -',			'mandala'),
			'bounceIn'			=> esc_html__('Bounce In',			'mandala'),
			'bounceInUp'		=> esc_html__('Bounce In Up',		'mandala'),
			'bounceInDown'		=> esc_html__('Bounce In Down',		'mandala'),
			'bounceInLeft'		=> esc_html__('Bounce In Left',		'mandala'),
			'bounceInRight'		=> esc_html__('Bounce In Right',	'mandala'),
			'elastic'			=> esc_html__('Elastic In',			'mandala'),
			'fadeIn'			=> esc_html__('Fade In',			'mandala'),
			'fadeInUp'			=> esc_html__('Fade In Up',			'mandala'),
			'fadeInUpSmall'		=> esc_html__('Fade In Up Small',	'mandala'),
			'fadeInUpBig'		=> esc_html__('Fade In Up Big',		'mandala'),
			'fadeInDown'		=> esc_html__('Fade In Down',		'mandala'),
			'fadeInDownBig'		=> esc_html__('Fade In Down Big',	'mandala'),
			'fadeInLeft'		=> esc_html__('Fade In Left',		'mandala'),
			'fadeInLeftBig'		=> esc_html__('Fade In Left Big',	'mandala'),
			'fadeInRight'		=> esc_html__('Fade In Right',		'mandala'),
			'fadeInRightBig'	=> esc_html__('Fade In Right Big',	'mandala'),
			'flipInX'			=> esc_html__('Flip In X',			'mandala'),
			'flipInY'			=> esc_html__('Flip In Y',			'mandala'),
			'lightSpeedIn'		=> esc_html__('Light Speed In',		'mandala'),
			'rotateIn'			=> esc_html__('Rotate In',			'mandala'),
			'rotateInUpLeft'	=> esc_html__('Rotate In Down Left','mandala'),
			'rotateInUpRight'	=> esc_html__('Rotate In Up Right',	'mandala'),
			'rotateInDownLeft'	=> esc_html__('Rotate In Up Left',	'mandala'),
			'rotateInDownRight'	=> esc_html__('Rotate In Down Right','mandala'),
			'rollIn'			=> esc_html__('Roll In',			'mandala'),
			'slideInUp'			=> esc_html__('Slide In Up',		'mandala'),
			'slideInDown'		=> esc_html__('Slide In Down',		'mandala'),
			'slideInLeft'		=> esc_html__('Slide In Left',		'mandala'),
			'slideInRight'		=> esc_html__('Slide In Right',		'mandala'),
			'wipeInLeftTop'		=> esc_html__('Wipe In Left Top',	'mandala'),
			'zoomIn'			=> esc_html__('Zoom In',			'mandala'),
			'zoomInUp'			=> esc_html__('Zoom In Up',			'mandala'),
			'zoomInDown'		=> esc_html__('Zoom In Down',		'mandala'),
			'zoomInLeft'		=> esc_html__('Zoom In Left',		'mandala'),
			'zoomInRight'		=> esc_html__('Zoom In Right',		'mandala')
		);
		return $prepend_inherit ? mandala_array_merge(array('inherit' => esc_html__("Inherit", 'mandala')), $list) : $list;
	}
}


// Return list of the out animations
if ( !function_exists( 'mandala_get_list_animations_out' ) ) {
	function mandala_get_list_animations_out($prepend_inherit=false) {
		$list = array(
			'none'			=> esc_html__('- None -',			'mandala'),
			'bounceOut'		=> esc_html__('Bounce Out',			'mandala'),
			'bounceOutUp'	=> esc_html__('Bounce Out Up',		'mandala'),
			'bounceOutDown'	=> esc_html__('Bounce Out Down',	'mandala'),
			'bounceOutLeft'	=> esc_html__('Bounce Out Left',	'mandala'),
			'bounceOutRight'=> esc_html__('Bounce Out Right',	'mandala'),
			'fadeOut'		=> esc_html__('Fade Out',			'mandala'),
			'fadeOutUp'		=> esc_html__('Fade Out Up',		'mandala'),
			'fadeOutUpBig'	=> esc_html__('Fade Out Up Big',	'mandala'),
			'fadeOutDownSmall'	=> esc_html__('Fade Out Down Small','mandala'),
			'fadeOutDownBig'=> esc_html__('Fade Out Down Big',	'mandala'),
			'fadeOutDown'	=> esc_html__('Fade Out Down',		'mandala'),
			'fadeOutLeft'	=> esc_html__('Fade Out Left',		'mandala'),
			'fadeOutLeftBig'=> esc_html__('Fade Out Left Big',	'mandala'),
			'fadeOutRight'	=> esc_html__('Fade Out Right',		'mandala'),
			'fadeOutRightBig'=> esc_html__('Fade Out Right Big','mandala'),
			'flipOutX'		=> esc_html__('Flip Out X',			'mandala'),
			'flipOutY'		=> esc_html__('Flip Out Y',			'mandala'),
			'hinge'			=> esc_html__('Hinge Out',			'mandala'),
			'lightSpeedOut'	=> esc_html__('Light Speed Out',	'mandala'),
			'rotateOut'		=> esc_html__('Rotate Out',			'mandala'),
			'rotateOutUpLeft'	=> esc_html__('Rotate Out Down Left',	'mandala'),
			'rotateOutUpRight'	=> esc_html__('Rotate Out Up Right',	'mandala'),
			'rotateOutDownLeft'	=> esc_html__('Rotate Out Up Left',		'mandala'),
			'rotateOutDownRight'=> esc_html__('Rotate Out Down Right',	'mandala'),
			'rollOut'			=> esc_html__('Roll Out',		'mandala'),
			'slideOutUp'		=> esc_html__('Slide Out Up',	'mandala'),
			'slideOutDown'		=> esc_html__('Slide Out Down',	'mandala'),
			'slideOutLeft'		=> esc_html__('Slide Out Left',	'mandala'),
			'slideOutRight'		=> esc_html__('Slide Out Right','mandala'),
			'zoomOut'			=> esc_html__('Zoom Out',		'mandala'),
			'zoomOutUp'			=> esc_html__('Zoom Out Up',	'mandala'),
			'zoomOutDown'		=> esc_html__('Zoom Out Down',	'mandala'),
			'zoomOutLeft'		=> esc_html__('Zoom Out Left',	'mandala'),
			'zoomOutRight'		=> esc_html__('Zoom Out Right',	'mandala')
		);
		return $prepend_inherit ? mandala_array_merge(array('inherit' => esc_html__("Inherit", 'mandala')), $list) : $list;
	}
}

// Return classes list for the specified animation
if (!function_exists('mandala_get_animation_classes')) {
	function mandala_get_animation_classes($animation, $speed='normal', $loop='none') {
		return mandala_is_off($animation) ? '' : 'animated '.esc_attr($animation).' '.esc_attr($speed).(!mandala_is_off($loop) ? ' '.esc_attr($loop) : '');
	}
}

// Return custom sidebars list, prepended inherit and main sidebars item (if need)
if ( !function_exists( 'mandala_get_list_sidebars' ) ) {
	function mandala_get_list_sidebars($prepend_inherit=false) {
		if (($list = mandala_storage_get('list_sidebars'))=='') {
			$list = apply_filters('mandala_filter_list_sidebars', array(
				'sidebar_widgets'		=> esc_html__('Sidebar Widgets', 'mandala'),
				'header_widgets'		=> esc_html__('Header Widgets', 'mandala'),
				'above_page_widgets'	=> esc_html__('Above Page Widgets', 'mandala'),
				'above_content_widgets' => esc_html__('Above Content Widgets', 'mandala'),
				'below_content_widgets' => esc_html__('Below Content Widgets', 'mandala'),
				'below_page_widgets' 	=> esc_html__('Below Page Widgets', 'mandala'),
				'footer_widgets'		=> esc_html__('Footer Widgets', 'mandala')
				)
			);
			$custom_sidebars_number = max(0, min(10, mandala_get_theme_setting('custom_sidebars')));
			if (count(array($custom_sidebars_number)) > 0) {
				for ($i=1; $i <= $custom_sidebars_number; $i++) {
					$list['custom_widgets_'.intval($i)] = sprintf(esc_html__('Custom Widgets %d', 'mandala'), $i);
				}
			}
			mandala_storage_set('list_sidebars', $list);
		}
		return $prepend_inherit ? mandala_array_merge(array('inherit' => esc_html__("Inherit", 'mandala')), $list) : $list;
	}
}

// Return sidebars positions
if ( !function_exists( 'mandala_get_list_sidebars_positions' ) ) {
	function mandala_get_list_sidebars_positions($prepend_inherit=false) {
		$list = array(
			'left'  => esc_html__('Left',  'mandala'),
			'right' => esc_html__('Right', 'mandala')
		);
		return $prepend_inherit ? mandala_array_merge(array('inherit' => esc_html__("Inherit", 'mandala')), $list) : $list;
	}
}

// Return blog styles list, prepended inherit
if ( !function_exists( 'mandala_get_list_blog_styles' ) ) {
	function mandala_get_list_blog_styles($prepend_inherit=false) {
		$list = apply_filters('mandala_filter_list_blog_styles', array(
			'excerpt'	=> esc_html__('Excerpt','mandala'),
			'classic_2'	=> esc_html__('Classic /2 columns/',	'mandala'),
			'classic_3'	=> esc_html__('Classic /3 columns/',	'mandala'),
			'portfolio_2' => esc_html__('Portfolio /2 columns/','mandala'),
			'portfolio_3' => esc_html__('Portfolio /3 columns/','mandala')
			)
		);
		return $prepend_inherit ? mandala_array_merge(array('inherit' => esc_html__("Inherit", 'mandala')), $list) : $list;
	}
}


// Return list of categories
if ( !function_exists( 'mandala_get_list_categories' ) ) {
	function mandala_get_list_categories($prepend_inherit=false) {
		if (($list = mandala_storage_get('list_categories'))=='') {
			$list = array();
			$args = array(
				'type'                     => 'post',
				'child_of'                 => 0,
				'parent'                   => '',
				'orderby'                  => 'name',
				'order'                    => 'ASC',
				'hide_empty'               => 0,
				'hierarchical'             => 1,
				'exclude'                  => '',
				'include'                  => '',
				'number'                   => '',
				'taxonomy'                 => 'category',
				'pad_counts'               => false );
			$taxonomies = get_categories( $args );
			if (is_array($taxonomies) && count($taxonomies) > 0) {
				foreach ($taxonomies as $cat) {
					$list[$cat->term_id] = $cat->name;
				}
			}
			mandala_storage_set('list_categories', $list);
		}
		return $prepend_inherit ? mandala_array_merge(array('inherit' => esc_html__("Inherit", 'mandala')), $list) : $list;
	}
}


// Return list of taxonomies
if ( !function_exists( 'mandala_get_list_terms' ) ) {
	function mandala_get_list_terms($prepend_inherit=false, $taxonomy='category') {
		if (($list = mandala_storage_get('list_taxonomies_'.($taxonomy)))=='') {
			$list = array();
			$args = array(
				'child_of'                 => 0,
				'parent'                   => '',
				'orderby'                  => 'name',
				'order'                    => 'ASC',
				'hide_empty'               => 0,
				'hierarchical'             => 1,
				'exclude'                  => '',
				'include'                  => '',
				'number'                   => '',
				'taxonomy'                 => $taxonomy,
				'pad_counts'               => false );
			$taxonomies = get_terms( $taxonomy, $args );
			if (is_array($taxonomies) && count($taxonomies) > 0) {
				foreach ($taxonomies as $cat) {
					$list[$cat->term_id] = $cat->name;
				}
			}
			mandala_storage_set('list_taxonomies_'.($taxonomy), $list);
		}
		return $prepend_inherit ? mandala_array_merge(array('inherit' => esc_html__("Inherit", 'mandala')), $list) : $list;
	}
}

// Return list of post's types
if ( !function_exists( 'mandala_get_list_posts_types' ) ) {
	function mandala_get_list_posts_types($prepend_inherit=false) {
		if (($list = mandala_storage_get('list_posts_types'))=='') {
			$list = apply_filters('mandala_filter_list_posts_types', array(
				'post' => esc_html__('Post', 'mandala')
			));
			mandala_storage_set('list_posts_types', $list);
		}
		return $prepend_inherit ? mandala_array_merge(array('inherit' => esc_html__("Inherit", 'mandala')), $list) : $list;
	}
}


// Return list post items from any post type and taxonomy
if ( !function_exists( 'mandala_get_list_posts' ) ) {
	function mandala_get_list_posts($prepend_inherit=false, $opt=array()) {
		$opt = array_merge(array(
			'post_type'			=> 'post',
			'post_status'		=> 'publish',
			'taxonomy'			=> 'category',
			'taxonomy_value'	=> '',
			'posts_per_page'	=> -1,
			'orderby'			=> 'post_date',
			'order'				=> 'desc',
			'return'			=> 'id'
			), is_array($opt) ? $opt : array('post_type'=>$opt));

		$hash = 'list_posts_'.($opt['post_type']).'_'.($opt['taxonomy']).'_'.($opt['taxonomy_value']).'_'.($opt['orderby']).'_'.($opt['order']).'_'.($opt['return']).'_'.($opt['posts_per_page']);
		if (($list = mandala_storage_get($hash))=='') {
			$list = array();
			$list['none'] = esc_html__("- Not selected -", 'mandala');
			$args = array(
				'post_type' => $opt['post_type'],
				'post_status' => $opt['post_status'],
				'posts_per_page' => $opt['posts_per_page'],
				'ignore_sticky_posts' => true,
				'orderby'	=> $opt['orderby'],
				'order'		=> $opt['order']
			);
			if (!empty($opt['taxonomy_value'])) {
				$args['tax_query'] = array(
					array(
						'taxonomy' => $opt['taxonomy'],
						'field' => (int) $opt['taxonomy_value'] > 0 ? 'id' : 'slug',
						'terms' => $opt['taxonomy_value']
					)
				);
			}
			$posts = get_posts( $args );
			if (is_array($posts) && count($posts) > 0) {
				foreach ($posts as $post) {
					$list[$opt['return']=='id' ? $post->ID : $post->post_title] = $post->post_title;
				}
			}
			mandala_storage_set($hash, $list);
		}
		return $prepend_inherit ? mandala_array_merge(array('inherit' => esc_html__("Inherit", 'mandala')), $list) : $list;
	}
}


// Return list of registered users
if ( !function_exists( 'mandala_get_list_users' ) ) {
	function mandala_get_list_users($prepend_inherit=false, $roles=array('administrator', 'editor', 'author', 'contributor', 'shop_manager')) {
		if (($list = mandala_storage_get('list_users'))=='') {
			$list = array();
			$list['none'] = esc_html__("- Not selected -", 'mandala');
			$args = array(
				'orderby'	=> 'display_name',
				'order'		=> 'ASC' );
			$users = get_users( $args );
			if (is_array($users) && count($users) > 0) {
				foreach ($users as $user) {
					$accept = true;
					if (is_array($user->roles)) {
						if (is_array($user->roles) && count($user->roles) > 0) {
							$accept = false;
							foreach ($user->roles as $role) {
								if (in_array($role, $roles)) {
									$accept = true;
									break;
								}
							}
						}
					}
					if ($accept) $list[$user->user_login] = $user->display_name;
				}
			}
			mandala_storage_set('list_users', $list);
		}
		return $prepend_inherit ? mandala_array_merge(array('inherit' => esc_html__("Inherit", 'mandala')), $list) : $list;
	}
}

// Return menus list, prepended inherit
if ( !function_exists( 'mandala_get_list_menus' ) ) {
	function mandala_get_list_menus($prepend_inherit=false) {
		if (($list = mandala_storage_get('list_menus'))=='') {
			$list = array();
			$list['default'] = esc_html__("Default", 'mandala');
			$menus = wp_get_nav_menus();
			if (is_array($menus) && count($menus) > 0) {
				foreach ($menus as $menu) {
					$list[$menu->slug] = $menu->name;
				}
			}
			mandala_storage_set('list_menus', $list);
		}
		return $prepend_inherit ? mandala_array_merge(array('inherit' => esc_html__("Inherit", 'mandala')), $list) : $list;
	}
}

// Return iconed classes list
if ( !function_exists( 'mandala_get_list_icons' ) ) {
	function mandala_get_list_icons($prepend_inherit=false) {
		static $list = false;
		if (!is_array($list)) 
			$list = !is_admin() ? array() : mandala_parse_icons_classes(mandala_get_file_dir("css/fontello/css/fontello-codes.css"));
		return $prepend_inherit ? mandala_array_merge(array('inherit' => esc_html__("Inherit", 'mandala')), $list) : $list;
	}
}
?>