<?php
/**
 * The template for homepage posts with "Portfolio" style
 *
 * @package WordPress
 * @subpackage MANDALA
 * @since MANDALA 1.0
 */

mandala_storage_set('blog_archive', true);

// Load scripts for both 'Gallery' and 'Portfolio' layouts!
wp_enqueue_script( 'classie', mandala_get_file_url('js/theme.gallery/classie.min.js'), array(), null, true );
wp_enqueue_script( 'imagesloaded', mandala_get_file_url('js/theme.gallery/imagesloaded.min.js'), array(), null, true );
wp_enqueue_script( 'masonry', mandala_get_file_url('js/theme.gallery/masonry.min.js'), array(), null, true );
wp_enqueue_script( 'mandala-gallery-script', mandala_get_file_url('js/theme.gallery/theme.gallery.js'), array(), null, true );

get_header(); 

if (have_posts()) {

	echo get_query_var('blog_archive_start');

	$mandala_stickies = is_home() ? get_option( 'sticky_posts' ) : false;
	$mandala_sticky_out = is_array($mandala_stickies) && count($mandala_stickies) > 0 && get_query_var( 'paged' ) < 1;
	
	// Show filters
	$mandala_cat = mandala_get_theme_option('parent_cat');
	$mandala_post_type = mandala_get_theme_option('post_type');
	$mandala_taxonomy = mandala_get_post_type_taxonomy($mandala_post_type);
	$mandala_show_filters = mandala_get_theme_option('show_filters');
	$mandala_tabs = array();
	if (!mandala_is_off($mandala_show_filters)) {
		$mandala_args = array(
			'type'			=> $mandala_post_type,
			'child_of'		=> $mandala_cat,
			'orderby'		=> 'name',
			'order'			=> 'ASC',
			'hide_empty'	=> 1,
			'hierarchical'	=> 0,
			'exclude'		=> '',
			'include'		=> '',
			'number'		=> '',
			'taxonomy'		=> $mandala_taxonomy,
			'pad_counts'	=> false
		);
		$mandala_portfolio_list = get_terms($mandala_args);
		if (is_array($mandala_portfolio_list) && count($mandala_portfolio_list) > 0) {
			$mandala_tabs[$mandala_cat] = esc_html__('All', 'mandala');
			foreach ($mandala_portfolio_list as $mandala_term) {
				if (isset($mandala_term->term_id)) $mandala_tabs[$mandala_term->term_id] = $mandala_term->name;
			}
		}
	}
	if (count($mandala_tabs) > 0) {
		$mandala_portfolio_filters_ajax = true;
		$mandala_portfolio_filters_active = $mandala_cat;
		$mandala_portfolio_filters_id = 'portfolio_filters';
		if (!is_customize_preview())
			wp_enqueue_script('jquery-ui-tabs', false, array('jquery', 'jquery-ui-core'), null, true);
		?>
		<div class="portfolio_filters mandala_tabs mandala_tabs_ajax">
			<ul class="portfolio_titles mandala_tabs_titles">
				<?php
				foreach ($mandala_tabs as $mandala_id=>$mandala_title) {
					?><li><a href="<?php echo esc_url(mandala_get_hash_link(sprintf('#%s_%s_content', $mandala_portfolio_filters_id, $mandala_id))); ?>" data-tab="<?php echo esc_attr($mandala_id); ?>"><?php echo esc_html($mandala_title); ?></a></li><?php
				}
				?>
			</ul>
			<?php
			$mandala_ppp = mandala_get_theme_option('posts_per_page');
			if (mandala_is_inherit($mandala_ppp)) $mandala_ppp = '';
			foreach ($mandala_tabs as $mandala_id=>$mandala_title) {
				$mandala_portfolio_need_content = $mandala_id==$mandala_portfolio_filters_active || !$mandala_portfolio_filters_ajax;
				?>
				<div id="<?php echo esc_attr(sprintf('%s_%s_content', $mandala_portfolio_filters_id, $mandala_id)); ?>"
					class="portfolio_content mandala_tabs_content"
					data-blog-template="<?php echo esc_attr(mandala_storage_get('blog_template')); ?>"
					data-blog-style="<?php echo esc_attr(mandala_get_theme_option('blog_style')); ?>"
					data-posts-per-page="<?php echo esc_attr($mandala_ppp); ?>"
					data-post-type="<?php echo esc_attr($mandala_post_type); ?>"
					data-taxonomy="<?php echo esc_attr($mandala_taxonomy); ?>"
					data-cat="<?php echo esc_attr($mandala_id); ?>"
					data-parent-cat="<?php echo esc_attr($mandala_cat); ?>"
					data-need-content="<?php echo (false===$mandala_portfolio_need_content ? 'true' : 'false'); ?>"
				>
					<?php
					if ($mandala_portfolio_need_content) 
						mandala_show_portfolio_posts(array(
							'cat' => $mandala_id,
							'parent_cat' => $mandala_cat,
							'taxonomy' => $mandala_taxonomy,
							'post_type' => $mandala_post_type,
							'page' => 1,
							'sticky' => $mandala_sticky_out
							)
						);
					?>
				</div>
				<?php
			}
			?>
		</div>
		<?php
	} else {
		mandala_show_portfolio_posts(array(
			'cat' => $mandala_cat,
			'parent_cat' => $mandala_cat,
			'taxonomy' => $mandala_taxonomy,
			'post_type' => $mandala_post_type,
			'page' => 1,
			'sticky' => $mandala_sticky_out
			)
		);
	}

	echo get_query_var('blog_archive_end');

} else {

	if ( is_search() )
		get_template_part( 'content', 'none-search' );
	else
		get_template_part( 'content', 'none-archive' );

}

get_footer();
?>