<?php
/* Essential Grid support functions
------------------------------------------------------------------------------- */


// Theme init priorities:
// 9 - register other filters (for installer, etc.)
if (!function_exists('mandala_essential_grid_theme_setup9')) {
	add_action( 'after_setup_theme', 'mandala_essential_grid_theme_setup9', 9 );
	function mandala_essential_grid_theme_setup9() {
		if (mandala_exists_essential_grid()) {
			add_action( 'wp_enqueue_scripts', 							'mandala_essential_grid_frontend_scripts', 1100 );
			add_filter( 'mandala_filter_merge_styles',					'mandala_essential_grid_merge_styles' );
			add_filter( 'mandala_filter_get_css',						'mandala_essential_grid_get_css', 10, 3 );
		}
		if (is_admin()) {
			add_filter( 'mandala_filter_tgmpa_required_plugins',		'mandala_essential_grid_tgmpa_required_plugins' );
		}
	}
}

// Check if plugin installed and activated
if ( !function_exists( 'mandala_exists_essential_grid' ) ) {
	function mandala_exists_essential_grid() {
		return defined('EG_PLUGIN_PATH') || defined( 'ESG_PLUGIN_PATH' );
	}
}

// Filter to add in the required plugins list
if ( !function_exists( 'mandala_essential_grid_tgmpa_required_plugins' ) ) {
	
	function mandala_essential_grid_tgmpa_required_plugins($list=array()) {
		if (in_array('essential-grid', mandala_storage_get('required_plugins'))) {
			$path = mandala_get_file_dir('plugins/essential-grid/essential-grid.zip');
			if (file_exists($path)) {
				$list[] = array(
						'name' 		=> esc_html__('Essential Grid', 'mandala'),
						'slug' 		=> 'essential-grid',
						'version'	=> '3.0.17.1',
						'source'	=> $path,
						'required' 	=> false
					);
			}
		}			
		return $list;
	}
}
	
// Enqueue plugin's custom styles
if ( !function_exists( 'mandala_essential_grid_frontend_scripts' ) ) {
	
	function mandala_essential_grid_frontend_scripts() {
		if (mandala_is_on(mandala_get_theme_option('debug_mode')) && file_exists(mandala_get_file_dir('plugins/essential-grid/essential-grid.css')))
			wp_enqueue_style( 'mandala-essential-grid',  mandala_get_file_url('plugins/essential-grid/essential-grid.css'), array(), null );
	}
}
	
// Merge custom styles
if ( !function_exists( 'mandala_essential_grid_merge_styles' ) ) {
	
	function mandala_essential_grid_merge_styles($list) {
		$list[] = 'plugins/essential-grid/essential-grid.css';
		return $list;
	}
}



// Add plugin's specific styles into color scheme
//------------------------------------------------------------------------

// Add styles into CSS
if ( !function_exists( 'mandala_essential_grid_get_css' ) ) {
	
	function mandala_essential_grid_get_css($css, $colors, $fonts) {
		if (isset($css['fonts']) && $fonts) {
			$css['fonts'] .= <<<CSS

CSS;
		}

		if (isset($css['colors']) && $colors) {
			$css['colors'] .= <<<CSS

.cafe-skin .esg-entry-cover .esg-overlay {
	background-image: linear-gradient(127deg, {$colors['accent2_07']} 0%, {$colors['accent1_07']} 100%);
}
.cafe-skin .eg-custom-skin-1-element-0 i {
	color: {$colors['inverse_dark']};
}
.cafe-skin .eg-custom-skin-1-element-0:hover i {
	color: {$colors['text_dark_07']};
}

.classes-skin .esg-entry-cover .esg-overlay {
	background-image: linear-gradient(127deg, {$colors['accent2_07']} 0%, {$colors['accent1_07']} 100%);
}
.classes-skin .eg-custom-skin-2-element-31-a i {
	color: {$colors['inverse_dark']};
}
.classes-skin .eg-custom-skin-2-element-31-a:hover i {
	color: {$colors['text_dark_07']};
}
.classes-skin .sc_courses_item_link .sc_item_button .sc_button:before,
.classes-skin .sc_courses_item_link .sc_item_button .sc_button:after,
.classes-skin .sc_courses_item_link .sc_item_button .sc_button{
	color: {$colors['text_light']};
}
.classes-skin .sc_courses_item_link .sc_item_button .sc_button:hover:before,
.classes-skin .sc_courses_item_link .sc_item_button .sc_button:hover:after,
.classes-skin .sc_courses_item_link .sc_item_button .sc_button:hover{
	color: {$colors['text_link']} !important;
}

.classes-skin .esg-entry-media-wrapper .esg-entry-media:after {
	border-color: {$colors['bg_color_04']};
}

.classes-skin .esg-navigationbutton {
	color: {$colors['text_light']};
	border-color: {$colors['alter_text_01']};
}

.classes-skin .esg-navigationbutton:hover, 
.classes-skin .esg-navigationbutton.selected {
	color: {$colors['inverse_dark']};
	background-color: {$colors['accent1']};
	border-color: {$colors['accent1']};
}

CSS;
		}
		
		return $css;
	}
}
?>