<?php
/* Mail Chimp support functions
------------------------------------------------------------------------------- */

// Theme init priorities:
// 9 - register other filters (for installer, etc.)
if (!function_exists('mandala_mailchimp_theme_setup9')) {
	add_action( 'after_setup_theme', 'mandala_mailchimp_theme_setup9', 9 );
	function mandala_mailchimp_theme_setup9() {
		if (mandala_exists_mailchimp()) {
			add_action( 'wp_enqueue_scripts',							'mandala_mailchimp_frontend_scripts', 1100 );
			add_filter( 'mandala_filter_merge_styles',					'mandala_mailchimp_merge_styles');
			add_filter( 'mandala_filter_get_css',						'mandala_mailchimp_get_css', 10, 3);
		}
		if (is_admin()) {
			add_filter( 'mandala_filter_tgmpa_required_plugins',		'mandala_mailchimp_tgmpa_required_plugins' );
		}
	}
}

// Check if plugin installed and activated
if ( !function_exists( 'mandala_exists_mailchimp' ) ) {
	function mandala_exists_mailchimp() {
		return function_exists('__mc4wp_load_plugin') || defined('MC4WP_VERSION');
	}
}

// Filter to add in the required plugins list
if ( !function_exists( 'mandala_mailchimp_tgmpa_required_plugins' ) ) {
	
	function mandala_mailchimp_tgmpa_required_plugins($list=array()) {
		if (in_array('mailchimp-for-wp', mandala_storage_get('required_plugins')))
			$list[] = array(
				'name' 		=> esc_html__('MailChimp for WP', 'mandala'),
				'slug' 		=> 'mailchimp-for-wp',
				'required' 	=> false
			);
		return $list;
	}
}



// Custom styles and scripts
//------------------------------------------------------------------------

// Enqueue custom styles
if ( !function_exists( 'mandala_mailchimp_frontend_scripts' ) ) {
	
	function mandala_mailchimp_frontend_scripts() {
		if (mandala_exists_mailchimp()) {
			if (mandala_is_on(mandala_get_theme_option('debug_mode')) && file_exists(mandala_get_file_dir('plugins/mailchimp-for-wp/mailchimp-for-wp.css')))
				wp_enqueue_style( 'mandala-mailchimp-for-wp',  mandala_get_file_url('plugins/mailchimp-for-wp/mailchimp-for-wp.css'), array(), null );
		}
	}
}
	
// Merge custom styles
if ( !function_exists( 'mandala_mailchimp_merge_styles' ) ) {
	
	function mandala_mailchimp_merge_styles($list) {
		$list[] = 'plugins/mailchimp-for-wp/mailchimp-for-wp.css';
		return $list;
	}
}

// Add css styles into global CSS stylesheet
if (!function_exists('mandala_mailchimp_get_css')) {
	
	function mandala_mailchimp_get_css($css, $colors, $fonts) {
		
		if (isset($css['fonts']) && $fonts) {
			$css['fonts'] .= <<<CSS

CSS;
		}
		
		if (isset($css['colors']) && $colors) {
			$css['colors'] .= <<<CSS

.mc4wp-form input[type="email"] {
	background-color: {$colors['alter_dark']};
	border-color: {$colors['alter_dark']};
	color: {$colors['input_text']};
}
.mc4wp-form input[type="email"]:hover {
	color: {$colors['text_link']};
}
.mc4wp-form button:hover i{
	color: {$colors['text_link']};
}
.scheme_dark .mc4wp-form button:hover i{
	color: {$colors['text_hover']};
}
.mc4wp_style_2 .mc4wp-form input[type="email"] {
	color: {$colors['inverse_dark']};
}
.mc4wp_style_2 .mc4wp-form button i {
	color: {$colors['inverse_dark']};
}
.mc4wp_style_2 .mc4wp-form button:hover i {
	color: {$colors['text_dark']};
}

.mc4wp_style_2 .mc4wp-form input::-webkit-input-placeholder {color:{$colors['inverse_dark']};}
.mc4wp_style_2 .mc4wp-form input::-moz-placeholder          {color:{$colors['inverse_dark']};}/* Firefox 19+ */
.mc4wp_style_2 .mc4wp-form input:-moz-placeholder           {color:{$colors['inverse_dark']};}/* Firefox 18- */
.mc4wp_style_2 .mc4wp-form input:-ms-input-placeholder      {color:{$colors['inverse_dark']};}


CSS;
		}

		return $css;
	}
}
?>